/*
 * tronDraw.c
 * Drawing functions for Homework 4.
 *
 */

#include "tron.h"
#include "GP142.h"

/******************************************************************************
 * Symbolic constants.  There are other symbolic constants in tron.h.
 ******************************************************************************/

/* Colors */
#define BORDER_COLOR		BLUE
#define BACKGROUND_COLOR	BLACK
#define PLAYER_COLOR		YELLOW
#define PLAYER_DOT_COLOR	RED
#define ENEMY_COLOR			MAGENTA
#define BULLET_COLOR		WHITE
#define TEXT_COLOR			WHITE

/* For drawing GP142 filled primitives, use this as the line width. */
#define FILL		0

/* Screen element dimensions */
#define FONT_SIZE			12
#define TEXT_Y				(GP142_YMAX - 20)
#define LEVEL_TEXT_X		(-GP142_XMAX + 10)
#define LIVES_TEXT_X		0
#define SCORE_TEXT_X		(GP142_XMAX/2)
#define MESSAGE_TEXT_X		(int)(-GP142_XMAX * 2.0/3.0) /* To display game messages */
#define MESSAGE_TEXT_Y		30
#define MESSAGE_TEXT_SIZE	24

/******************************************************************************
 * Function prototypes.  See the function definitions for 
 * descriptions of what they do.  Other prototypes are in tron.h.
 ******************************************************************************/
void drawLevel(int level);
void drawLives(int numLives);
void drawScore(int score);




/****************************
 * FUNCTION DEFINITIONS     *
 ****************************/

/******************************************************************************
 * drawBackground
 *
 * Draw the background and the frame around it.
 */
void drawBackground(void)
{
	GP142_rectangleXY(BORDER_COLOR, -GP142_XMAX, -GP142_YMAX, GP142_XMAX, GP142_YMAX, FILL);
	GP142_rectangleXY(BACKGROUND_COLOR, -GP142_XMAX+BOUNDARY_WIDTH, -GP142_YMAX+BOUNDARY_WIDTH, 
					  GP142_XMAX-BOUNDARY_WIDTH, GP142_YMAX-BOUNDARY_WIDTH, FILL);
}

/******************************************************************************
 * drawMessage
 *
 * Display an in-game message.  The parameter is of type char [], which for our
 * purposes is just a string (those things in quotes).  Don't worry if this
 * doesn't make sense -- strings aren't really covered until later.
 */
void drawMessage(char message[])
{
	GP142_printfXY(TEXT_COLOR, MESSAGE_TEXT_X, MESSAGE_TEXT_Y, MESSAGE_TEXT_SIZE,
				   message);
}


/******************************************************************************
 * drawPlayer
 *
 * Display the player at the given coordinates.  The x and y given are the
 * TOP LEFT corner of the bounding box.
 */
void drawPlayer(int x, int y, int playerFacing)
{
	int playerCenterX = x+PLAYER_WIDTH/2,
		playerCenterY = y+PLAYER_HEIGHT/2,
		dotX, dotY;

	/* Player body */
	GP142_rectangleXY(PLAYER_COLOR, x, y, x+PLAYER_WIDTH, y+PLAYER_HEIGHT, FILL);

	/* Dot to show player facing */
	dotX = playerCenterX + PLAYER_WIDTH/2 * xComponent(playerFacing);
	dotY = playerCenterY + PLAYER_HEIGHT/2 * yComponent(playerFacing);
	GP142_circleXY(PLAYER_DOT_COLOR, dotX, dotY, PLAYER_DOT_RADIUS);
}

/******************************************************************************
 * drawEnemy
 *
 * Display an enemy on the screen at the given coordinates.  The x and y given
 * are the TOP LEFT corner of the bounding box.
 */
void drawEnemy(int x, int y, int enemyStatus)
{
	if (enemyStatus == ENEMY_ALIVE)
	{
		GP142_ovalXY(ENEMY_COLOR, x, y, x + ENEMY_WIDTH, y + ENEMY_HEIGHT, FILL);
	}
}

/******************************************************************************
 * drawBullet
 * 
 * Display a bullet on the screen at the given coordinates.  The x and y given
 * are the TOP LEFT corner of the bounding box.
 */
void drawBullet(int x, int y, int bulletStatus, int bulletFacing)
{
	if (bulletStatus == BULLET_ALIVE)
	{
		GP142_ovalXY(BULLET_COLOR, x, y, x + BULLET_WIDTH, y + BULLET_HEIGHT, FILL);
	}
}

/******************************************************************************
 * drawBanner
 *
 * Draw a banner at the top of the screen with game information
 */
void drawBanner(int level, int numLives, int score)
{
	GP142_rectangleXY(BORDER_COLOR, -GP142_XMAX, GP142_YMAX, GP142_XMAX, 
					  GP142_YMAX - BANNER_HEIGHT, FILL);
	drawLevel(level);
	drawLives(numLives);
	drawScore(score);
}

/******************************************************************************
 * drawLevel
 *
 * Display a string saying the current level number.
 */
void drawLevel(int level)
{
	GP142_printfXY(TEXT_COLOR, LEVEL_TEXT_X, TEXT_Y, FONT_SIZE,
				   "Level %d", level);
}

/******************************************************************************
 * drawLives
 *
 * Display a representation of the current number of lives the player has.
 */
void drawLives(int numLives)
{
	GP142_printfXY(TEXT_COLOR, LIVES_TEXT_X, TEXT_Y, FONT_SIZE,
				   "Lives: %d", numLives);
}

/******************************************************************************
 * drawScore
 *
 * Display a string showing the player's current score.
 */
void drawScore(int score)
{
	GP142_printfXY(TEXT_COLOR, SCORE_TEXT_X, TEXT_Y, FONT_SIZE,
				   "Score: %d", score);
}
